@@ -9,7 +9,7 @@ our @ISA = qw( Exporter );
 
 our @EXPORT = qw( LoadArgs LoadPatterns ClearPatterns GetPatterns Process );
 
-our $VERSION = "2.2.0";
+our $VERSION = "2.3.0";
 
 
 sub new
@@ -222,11 +222,11 @@ sub RearrangePositionsOfTags
                 #which corresponds to the last element in the @counts
                 if ( @counts )
                 {
-                    $$position[ 1 ] = $counts[ $#counts ][ 1 ];
+                    $$position[ 1 ] = $counts[ -1 ][ 1 ];
                     $$position[ 2 ] = -1;   #not 1 for correct work of
                                             #ByPositions()
-                    $$position[ 3 ] = $counts[ $#counts ][ 0 ];
-                    $$position[ 4 ] = \$$patterns[ $counts[ $#counts ][ 0 ] ];
+                    $$position[ 3 ] = $counts[ -1 ][ 0 ];
+                    $$position[ 4 ] = \$$patterns[ $counts[ -1 ][ 0 ] ];
                 }
             }
         }
@@ -298,7 +298,7 @@ sub InsertTags
                 }
             }
         }
-        substr( $$string_ref, $$position[ 0 ] + $offset, 0 ) = $colortag;
+        substr( $$string_ref, $$position[ 0 ] + $offset, 0, $colortag);
         $offset += length( $colortag );
     }
 }
@@ -430,7 +430,7 @@ A. Radkov, E<lt>alexey.radkov@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2023 by A. Radkov.
+Copyright (C) 2008-2025 by A. Radkov.
 
 This is free software; you can redistribute it and/or modify it
 under the same terms as the Perl 5 programming language system itself.
